Package: causalDisco
Title: Tools for Causal Discovery on Observational Data
Version: 1.1.0
Authors@R: c(
    person(given = "Bjarke", family = "Hautop Kristensen", email = "bjarke.kristensen@sund.ku.dk", role = c("aut", "cre")),
    person(given = "Frederik", family = "Fabricius-Bjerre", email = "frederik@fabriciusbjerre.dk", role = "aut"),
    person(given = "Anne", family = "Helby Petersen", email = "ahpe@sund.ku.dk", role = "aut"),
    person(given = "Claus", family = "Thorn Ekstrøm", email = "ekstrom@sund.ku.dk", role = "aut"),
    person(given = "Tobias", family = "Ellegaard Larsen", email = "tobias.ellegaard@sund.ku.dk", role = "ctb")
  )
Description: Tools for causal structure learning from observational data, with emphasis on temporally
    ordered variables. The package implements the Temporal Peter–Clark (TPC) algorithm
    (Petersen, Osler & Ekstrøm, 2021; <doi:10.1093/aje/kwab087>), the Temporal Greedy
    Equivalence Search (TGES) algorithm (Larsen, Ekstrøm & Petersen, 2025; <doi:10.48550/arXiv.2502.06232>)
    and Temporal Fast Causal Inference (TFCI). It provides a unified framework for specifying background
    knowledge, which can be incorporated into the implemented algorithms from the R packages 'bnlearn'
    (Scutari, 2010; <doi:10.18637/jss.v035.i03>) and 'pcalg' (Kalish et al., 2012; <doi:10.18637/jss.v047.i11>),
    as well as the Java library 'Tetrad' (Scheines et al., 1998; <doi:10.1207/s15327906mbr3301_3>).
    The package further includes utilities for visualization, comparison, and evaluation of graph
    structures, facilitating performance evaluation and methodological studies.
License: GPL-2
URL: https://github.com/disco-coders/causalDisco,
        https://disco-coders.github.io/causalDisco/
BugReports: https://github.com/disco-coders/causalDisco/issues
Depends: R (>= 4.2.0)
Imports: bnlearn, caugi (>= 1.0.0), checkmate, cli, digest, dplyr,
        glue, gtools, lifecycle, methods, micd, pcalg, purrr, R6,
        readr, rlang, S7, stringr, tibble, tidyr, tidyselect
Suggests: knitr, mockery, quarto, RhpcBLASctl, rJava, rmarkdown,
        spelling, testthat (>= 3.0.0), withr, mice
VignetteBuilder: knitr, quarto
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
Collate: 'aaa-globals.R' 'aaa-iamb-family.R' 'aaa-init-helpers.R'
        'alg-bugs.R' 'bnlearn-search.R' 'boss-fci.R' 'boss.R'
        'cast-obj.R' 'caugi-helpers.R' 'causalDisco-package.R'
        'causalDisco-search.R' 'check-args.R'
        'check-knowledge-violations.R' 'conditional-independence.R'
        'constraint-based-run-helpers.R' 'data.R' 'disco-class.R'
        'disco-doc-helpers.R' 'disco-method.R' 'disco.R' 'edges.R'
        'engine-registry.R' 'extend-causaldisco-algs.R' 'fci.R' 'ges.R'
        'gfci.R' 'grasp-fci.R' 'grasp.R' 'gs.R' 'hc.R' 'iamb-family.R'
        'install-tetrad.R' 'knowledge-conversions.R'
        'knowledge-helpers.R' 'knowledge-manipulation.R'
        'knowledge-verbs.R' 'knowledge.R' 'make-tikz-helpers.R'
        'make-tikz.R' 'metric-helpers.R' 'metrics.R' 'misc.R' 'pc.R'
        'pcalg-search.R' 'pcalg-type-tests.R' 'plot.R'
        'print-helpers.R' 'runners.R' 'simulation.R' 'sp-fci.R'
        'tabu.R' 'tetrad-graph.R' 'tetrad-rdata-utils.R'
        'tetrad-search.R' 'tpc-run.R' 'tfci-run.R' 'tfci.R'
        'tges-run.R' 'tges.R' 'tpc.R' 'zzz.R'
NeedsCompilation: no
Packaged: 2026-04-13 14:34:46 UTC; bjarke
Author: Bjarke Hautop Kristensen [aut, cre],
  Frederik Fabricius-Bjerre [aut],
  Anne Helby Petersen [aut],
  Claus Thorn Ekstrøm [aut],
  Tobias Ellegaard Larsen [ctb]
Maintainer: Bjarke Hautop Kristensen <bjarke.kristensen@sund.ku.dk>
Repository: CRAN
Date/Publication: 2026-04-13 15:40:02 UTC
Built: R 4.6.0; ; 2026-04-30 22:27:42 UTC; unix
