# Generated by roxygen2: do not edit by hand

S3method("$",Disco)
S3method("$<-",Disco)
S3method("+",Knowledge)
S3method("[[",Disco)
S3method("[[<-",Disco)
S3method(as_disco,EssGraph)
S3method(as_disco,default)
S3method(as_disco,fciAlgo)
S3method(as_disco,pcAlgo)
S3method(as_disco,tetrad_graph)
S3method(plot,Disco)
S3method(plot,Knowledge)
S3method(print,Disco)
S3method(print,Knowledge)
S3method(set_knowledge,Disco)
S3method(set_knowledge,disco_method)
S3method(summary,Disco)
S3method(summary,Knowledge)
export(BnlearnSearch)
export(CausalDiscoSearch)
export(PcalgSearch)
export(TetradSearch)
export(add_exo)
export(add_exogenous)
export(add_tier)
export(add_to_tier)
export(add_vars)
export(aid)
export(as_bnlearn_knowledge)
export(as_pcalg_constraints)
export(as_tetrad_knowledge)
export(boss)
export(boss_fci)
export(confusion)
export(convert_tiers_to_forbidden)
export(cor_test)
export(deparse_knowledge)
export(disco)
export(distribute_engine_args)
export(evaluate)
export(f1_score)
export(false_omission_rate)
export(fast_iamb)
export(fci)
export(fdr)
export(forbid_edge)
export(g1_score)
export(generate_dag_data)
export(ges)
export(get_tiers)
export(gfci)
export(grasp)
export(grasp_fci)
export(gs)
export(hd)
export(iamb)
export(iamb_fdr)
export(install_tetrad)
export(inter_iamb)
export(knowledge)
export(knowledge_to_caugi)
export(list_registered_tetrad_algorithms)
export(make_method)
export(make_runner)
export(make_tikz)
export(new_disco_method)
export(npv)
export(pc)
export(precision)
export(recall)
export(reg_test)
export(register_tetrad_algorithm)
export(remove_edge)
export(remove_tiers)
export(remove_vars)
export(reorder_tiers)
export(reposition_tier)
export(require_edge)
export(reset_tetrad_alg_registry)
export(seq_tiers)
export(set_knowledge)
export(shd)
export(sim_dag)
export(sp_fci)
export(specificity)
export(tfci)
export(tfci_run)
export(tges)
export(tges_run)
export(tpc)
export(tpc_run)
export(unfreeze)
export(verify_tetrad)
importClassesFrom(pcalg,EssGraph)
importClassesFrom(pcalg,GaussL0penIntScore)
importClassesFrom(pcalg,Score)
importClassesFrom(pcalg,pcAlgo)
importFrom(R6,R6Class)
importFrom(bnlearn,pc.stable)
importFrom(caugi,aid)
importFrom(caugi,hd)
importFrom(caugi,shd)
importFrom(digest,digest)
importFrom(lifecycle,deprecated)
importFrom(methods,new)
importFrom(rlang,"!!")
importFrom(rlang,.data)
importFrom(tidyselect,contains)
importFrom(tidyselect,ends_with)
importFrom(tidyselect,eval_select)
importFrom(tidyselect,everything)
importFrom(tidyselect,matches)
importFrom(tidyselect,num_range)
importFrom(tidyselect,starts_with)
importFrom(utils,download.file)
